package org.apache.maven.announcement;

/* ====================================================================
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements.  See the NOTICE file distributed with
 *   this work for additional information regarding copyright ownership.
 *   The ASF licenses this file to You under the Apache License, Version 2.0
 *   (the "License"); you may not use this file except in compliance with
 *   the License.  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 * ====================================================================
 */

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

/**
 * Format text by wrapping it if it goes beyond some column position.
 *
 * @author <a href="mailto:vmassol@apache.org">Vincent Massol</a>
 *
 * @version $Id: Formatter.java 529166 2007-04-16 08:31:26Z ltheussl $
 */
public final class Formatter
{
    /**
     * Format text by wrapping it if it goes beyond the passed column value.
     *
     * @param text the text to format
     * @param column the max column position
     * @return the wrapped text
     */
    public List format(final String text, final int column)
    {
        StringTokenizer st = new StringTokenizer(text, " \t\r\n");
        List strings = new ArrayList();
        StringBuffer buffer = new StringBuffer();
        while (st.hasMoreTokens())
        {
            String token = st.nextToken();
            if (buffer.length() + token.length() <= column)
            {
                buffer.append(token);
                buffer.append(' ');
            }
            else
            {
                strings.add(buffer.toString());
                buffer = new StringBuffer();
                buffer.append(token);
                buffer.append(' ');
            }
        }
        strings.add(buffer.toString());
        return strings;
    }
}
